@@ -1,11 +1,11 @@
 import pandas as pd
 
-from pysuricata import profile, summarize, ReportConfig
+from pysuricata import ProfileConfig, profile, summarize
 
 
 def test_profile_returns_html_and_stats():
     df = pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
-    rep = profile(df, config=ReportConfig())
+    rep = profile(df, config=ProfileConfig())
     assert rep.html and isinstance(rep.html, str)
     assert rep.stats and isinstance(rep.stats, dict)
     assert rep.stats.get("dataset") is not None
